@@ -45,8 +45,8 @@ am_ready_cb (GObject      *source_object,
   TpAccountManager *account_manager = TP_ACCOUNT_MANAGER (source_object);
   AnerleyFeed *feed;
   ClutterActor *stage;
-  NbtkWidget *scroll_view;
-  NbtkWidget *icon_view;
+  ClutterActor *scroll_view;
+  ClutterActor *icon_view;
   ClutterModel *model;
   GError *error = NULL;
 
@@ -62,7 +62,7 @@ am_ready_cb (GObject      *source_object,
   stage = clutter_stage_get_default ();
   icon_view = anerley_tile_view_new (ANERLEY_FEED_MODEL (model));
 
-  scroll_view = nbtk_scroll_view_new ();
+  scroll_view = mx_scroll_view_new ();
   clutter_container_add_actor (CLUTTER_CONTAINER (stage),
                                CLUTTER_ACTOR (scroll_view));
   clutter_container_add_actor (CLUTTER_CONTAINER (scroll_view),
@@ -77,7 +77,7 @@ main (int    argc,
 {
   TpAccountManager *account_manager;
   gchar *path;
-  NbtkStyle *style;
+  MxStyle *style;
   GError *error = NULL;
 
   clutter_init (&argc, &argv);
@@ -86,9 +86,9 @@ main (int    argc,
                            "style.css",
                            NULL);
 
-  style = nbtk_style_get_default ();
+  style = mx_style_get_default ();
 
-  if (!nbtk_style_load_from_file (style,
+  if (!mx_style_load_from_file (style,
                                   path,
                                   &error))
   {
